#ifndef NT2_INCLUDE_FUNCTIONS_CAUCDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CAUCDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/caucdf.hpp>

#endif
